@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2010 Jeffrey Stedfast
+ *  Copyright (C) 2000-2012 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -26,9 +26,9 @@
 
 G_BEGIN_DECLS
 
-int g_mime_strcase_equal (gconstpointer v, gconstpointer v2);
+G_GNUC_INTERNAL int g_mime_strcase_equal (gconstpointer v, gconstpointer v2);
 
-guint g_mime_strcase_hash (gconstpointer key);
+G_GNUC_INTERNAL guint g_mime_strcase_hash (gconstpointer key);
 
 G_GNUC_INTERNAL char *g_mime_strdup_trim (const char *str);
 
