@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2011 Jeffrey Stedfast and Michael Zucchi
+ *  Copyright (C) 2000-2012 Jeffrey Stedfast and Michael Zucchi
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -102,7 +102,7 @@ static unsigned char tohex[16] = {
 
 /**
  * g_mime_content_encoding_from_string:
- * @str: string representing a Content-Transfer-Encoding value
+ * @str: a string representing a Content-Transfer-Encoding value
  *
  * Gets the appropriate #GMimeContentEncoding enumeration value based
  * on the input string.
@@ -117,6 +117,10 @@ g_mime_content_encoding_from_string (const char *str)
 		return GMIME_CONTENT_ENCODING_7BIT;
 	else if (!g_ascii_strcasecmp (str, "8bit"))
 		return GMIME_CONTENT_ENCODING_8BIT;
+	else if (!g_ascii_strcasecmp (str, "7-bit"))
+		return GMIME_CONTENT_ENCODING_7BIT;
+	else if (!g_ascii_strcasecmp (str, "8-bit"))
+		return GMIME_CONTENT_ENCODING_8BIT;
 	else if (!g_ascii_strcasecmp (str, "binary"))
 		return GMIME_CONTENT_ENCODING_BINARY;
 	else if (!g_ascii_strcasecmp (str, "base64"))
@@ -127,6 +131,8 @@ g_mime_content_encoding_from_string (const char *str)
 		return GMIME_CONTENT_ENCODING_UUENCODE;
 	else if (!g_ascii_strcasecmp (str, "x-uuencode"))
 		return GMIME_CONTENT_ENCODING_UUENCODE;
+	else if (!g_ascii_strcasecmp (str, "x-uue"))
+		return GMIME_CONTENT_ENCODING_UUENCODE;
 	else
 		return GMIME_CONTENT_ENCODING_DEFAULT;
 }
