@@ -384,7 +384,7 @@ gpg_ctx_new (GMimeGpgContext *ctx)
 	
 	stream = g_mime_stream_mem_new ();
 	gpg->diag = GMIME_STREAM_MEM (stream)->buffer;
-	charset = g_mime_locale_charset ();
+	charset = g_mime_charset_iconv_name (g_mime_locale_charset ());
 	if (g_ascii_strcasecmp (charset, "UTF-8") != 0) {
 		GMimeStream *fstream;
 		GMimeFilter *filter;
@@ -1312,9 +1312,11 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, GError **err)
 				cert->pubkey_algo = strtoul (status, &inend, 10);
 				if (inend == status || *inend != ' ') {
 					cert->pubkey_algo = 0;
+					g_object_unref (cert);
 					break;
 				}
 				
+				g_object_unref (cert);
 				status = inend + 1;
 				
 				/* third token is a dummy value which is always '0' */
