@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2014 Jeffrey Stedfast
+ *  Copyright (C) 2000-2012 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -398,7 +398,7 @@ multipart_add (GMimeMultipart *multipart, GMimeObject *part)
  * @multipart: a #GMimeMultipart object
  * @part: a #GMimeObject
  *
- * Appends a mime part to @multipart.
+ * Adds a mime part to the multipart.
  **/
 void
 g_mime_multipart_add (GMimeMultipart *multipart, GMimeObject *part)
@@ -443,10 +443,11 @@ multipart_insert (GMimeMultipart *multipart, int index, GMimeObject *part)
 /**
  * g_mime_multipart_insert:
  * @multipart: a #GMimeMultipart object
- * @part: a #GMimeObject
- * @index: the 0-based index to insert the part
+ * @part: mime part
+ * @index: position to insert the mime part
  *
- * Inserts @part into @multipart at the specified @index.
+ * Inserts the specified mime part into the multipart at the position
+ * @index.
  **/
 void
 g_mime_multipart_insert (GMimeMultipart *multipart, int index, GMimeObject *part)
@@ -474,9 +475,9 @@ multipart_remove (GMimeMultipart *multipart, GMimeObject *part)
 /**
  * g_mime_multipart_remove:
  * @multipart: a #GMimeMultipart object
- * @part: a #GMimeObject
+ * @part: mime part
  *
- * Removes the specified @part from @multipart.
+ * Removes the specified mime part from the multipart.
  *
  * Returns: %TRUE if the part was removed or %FALSE otherwise.
  **/
@@ -509,12 +510,12 @@ multipart_remove_at (GMimeMultipart *multipart, int index)
 /**
  * g_mime_multipart_remove_at:
  * @multipart: a #GMimeMultipart object
- * @index: the 0-based index of the part to remove
+ * @index: position of the mime part to remove
  *
- * Removes the part at the specified @index from @multipart.
+ * Removes the mime part at position @index from the multipart.
  *
- * Returns: (transfer full): the mime part that was removed or %NULL
- * if the part was not contained within the multipart.
+ * Returns: the mime part that was removed or %NULL if the part was
+ * not contained within the multipart.
  **/
 GMimeObject *
 g_mime_multipart_remove_at (GMimeMultipart *multipart, int index)
@@ -529,14 +530,14 @@ g_mime_multipart_remove_at (GMimeMultipart *multipart, int index)
 /**
  * g_mime_multipart_replace:
  * @multipart: a #GMimeMultipart object
- * @index: the 0-based index of the part to replace
+ * @index: position of the mime part to replace
  * @replacement: a #GMimeObject to use as the replacement
  *
- * Replaces the part at the specified @index within @multipart with
+ * Replaces the mime part at position @index within @multipart with
  * @replacement.
  *
- * Returns: (transfer full): the part that was replaced or %NULL
- * if the part was not contained within the multipart.
+ * Returns: the mime part that was replaced or %NULL if the part was
+ * not contained within the multipart.
  **/
 GMimeObject *
 g_mime_multipart_replace (GMimeMultipart *multipart, int index, GMimeObject *replacement)
@@ -575,11 +576,11 @@ multipart_get_part (GMimeMultipart *multipart, int index)
 /**
  * g_mime_multipart_get_part:
  * @multipart: a #GMimeMultipart object
- * @index: the 0-based index of the part
+ * @index: position of the mime part
  *
- * Gets the part at the specified @index within the multipart.
+ * Gets the mime part at position @index within the multipart.
  *
- * Returns: (transfer none): the part at position @index.
+ * Returns: the mime part at position @index.
  **/
 GMimeObject *
 g_mime_multipart_get_part (GMimeMultipart *multipart, int index)
@@ -608,7 +609,7 @@ multipart_contains (GMimeMultipart *multipart, GMimeObject *part)
 /**
  * g_mime_multipart_contains:
  * @multipart: a #GMimeMultipart object
- * @part: a #GMimeObject
+ * @part: mime part
  *
  * Checks if @part is contained within @multipart.
  *
@@ -642,11 +643,11 @@ multipart_index_of (GMimeMultipart *multipart, GMimeObject *part)
 /**
  * g_mime_multipart_index_of:
  * @multipart: a #GMimeMultipart object
- * @part: a #GMimeObject
+ * @part: mime part
  *
- * Gets the 0-based index of @part within @multipart.
+ * Gets the index of @part within @multipart.
  *
- * Returns: the 0-based index of @part within @multipart or %-1 if not found.
+ * Returns: the index of @part within @multipart or %-1 if not found.
  **/
 int
 g_mime_multipart_index_of (GMimeMultipart *multipart, GMimeObject *part)
@@ -669,9 +670,9 @@ multipart_get_count (GMimeMultipart *multipart)
  * g_mime_multipart_get_count:
  * @multipart: a #GMimeMultipart object
  *
- * Gets the number of parts contained within @multipart.
+ * Gets the number of mime parts contained within the multipart.
  *
- * Returns: the number of parts contained within @multipart.
+ * Returns: the number of mime parts contained within the multipart.
  **/
 int
 g_mime_multipart_get_count (GMimeMultipart *multipart)
@@ -710,6 +711,8 @@ read_random_pool (unsigned char *buffer, size_t bytes)
 #else
 	size_t i;
 	
+	srand ((unsigned int) time (NULL));
+	
 	for (i = 0; i < bytes; i++)
 		buffer[i] = (unsigned char) (rand () % 256);
 #endif
@@ -810,8 +813,7 @@ multipart_foreach (GMimeMultipart *multipart, GMimeObjectForeachFunc callback, g
 /**
  * g_mime_multipart_foreach: 
  * @multipart: a #GMimeMultipart
- * @callback: (scope call): function to call for each of @multipart's
- *   subparts.
+ * @callback: function to call for each of @multipart's subparts.
  * @user_data: user-supplied callback data
  * 
  * Recursively calls @callback on each of @multipart's subparts.
@@ -834,8 +836,8 @@ g_mime_multipart_foreach (GMimeMultipart *multipart, GMimeObjectForeachFunc call
  * Gets the mime part with the content-id @content_id from the
  * multipart @multipart.
  *
- * Returns: (transfer none): the #GMimeObject whose content-id matches
- * the search string, or %NULL if a match cannot be found.
+ * Returns: the #GMimeObject whose content-id matches the search string,
+ * or %NULL if a match cannot be found.
  **/
 GMimeObject *
 g_mime_multipart_get_subpart_from_content_id (GMimeMultipart *multipart, const char *content_id)
