@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2014 Jeffrey Stedfast
+ *  Copyright (C) 2000-2012 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -344,7 +344,6 @@ write_content (GMimePart *part, GMimeStream *stream)
 		content_stream = g_mime_data_wrapper_get_stream (part->content);
 		g_mime_stream_reset (content_stream);
 		nwritten = g_mime_stream_write_to_stream (content_stream, stream);
-		g_mime_stream_reset (content_stream);
 		
 		if (nwritten == -1)
 			return -1;
@@ -804,39 +803,13 @@ g_mime_part_get_best_content_encoding (GMimePart *mime_part, GMimeEncodingConstr
 }
 
 
-/**
- * g_mime_part_is_attachment:
- * @mime_part: a #GMimePart object
- *
- * Determines whether or not the part is an attachment based on the
- * value of the Content-Disposition header.
- *
- * Returns: %TRUE if the part is an attachment, otherwise %FALSE.
- *
- * Since: 2.6.21
- **/
-gboolean
-g_mime_part_is_attachment (GMimePart *mime_part)
-{
-	GMimeContentDisposition *disposition;
-	
-	g_return_val_if_fail (GMIME_IS_PART (mime_part), FALSE);
-	
-	disposition = g_mime_object_get_content_disposition ((GMimeObject *) mime_part);
-	
-	return disposition != NULL && g_mime_content_disposition_is_attachment (disposition);
-}
-
-
 /**
  * g_mime_part_set_filename:
  * @mime_part: a #GMimePart object
- * @filename: the file name
+ * @filename: the filename of the Mime Part's content
  *
  * Sets the "filename" parameter on the Content-Disposition and also sets the
  * "name" parameter on the Content-Type.
- *
- * Note: The @filename string should be in UTF-8.
  **/
 void
 g_mime_part_set_filename (GMimePart *mime_part, const char *filename)
@@ -854,12 +827,12 @@ g_mime_part_set_filename (GMimePart *mime_part, const char *filename)
  * g_mime_part_get_filename:
  * @mime_part: a #GMimePart object
  *
- * Gets the filename of the specificed mime part, or %NULL if the
- * @mime_part does not have the filename or name parameter set.
+ * Gets the filename of the specificed mime part, or %NULL if the mime
+ * part does not have the filename or name parameter set.
  *
- * Returns: the filename of the specified @mime_part or %NULL if
- * neither of the parameters is set. If a file name is set, the
- * returned string will be in UTF-8.
+ * Returns: the filename of the specified MIME Part. It first checks to
+ * see if the "filename" parameter was set on the Content-Disposition
+ * and if not then checks the "name" parameter in the Content-Type.
  **/
 const char *
 g_mime_part_get_filename (GMimePart *mime_part)
@@ -914,8 +887,7 @@ g_mime_part_set_content_object (GMimePart *mime_part, GMimeDataWrapper *content)
  * Gets the internal data-wrapper of the specified mime part, or %NULL
  * on error.
  *
- * Returns: (transfer none): the data-wrapper for the mime part's
- * contents.
+ * Returns: the data-wrapper for the mime part's contents.
  **/
 GMimeDataWrapper *
 g_mime_part_get_content_object (GMimePart *mime_part)
