@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2014 Jeffrey Stedfast
+ *  Copyright (C) 2000-2012 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -370,8 +370,6 @@ g_mime_stream_file_new (FILE *fp)
 	GMimeStreamFile *fstream;
 	gint64 start;
 	
-	g_return_val_if_fail (fp != NULL, NULL);
-	
 #ifdef G_OS_WIN32
 	_setmode (_fileno (fp), O_BINARY);
 #endif
@@ -407,8 +405,6 @@ g_mime_stream_file_new_with_bounds (FILE *fp, gint64 start, gint64 end)
 {
 	GMimeStreamFile *fstream;
 	
-	g_return_val_if_fail (fp != NULL, NULL);
-	
 #ifdef G_OS_WIN32
 	_setmode (_fileno (fp), O_BINARY);
 #endif
@@ -422,33 +418,6 @@ g_mime_stream_file_new_with_bounds (FILE *fp, gint64 start, gint64 end)
 }
 
 
-/**
- * g_mime_stream_file_new_for_path:
- * @path: the path to a file
- * @mode: as in fopen(3)
- *
- * Creates a new #GMimeStreamFile object for the specified @path.
- *
- * Returns: a stream using for reading and/or writing to the specified
- * file path or %NULL on error.
- *
- * Since: 2.6.18
- **/
-GMimeStream *
-g_mime_stream_file_new_for_path (const char *path, const char *mode)
-{
-	FILE *fp;
-	
-	g_return_val_if_fail (path != NULL, NULL);
-	g_return_val_if_fail (mode != NULL, NULL);
-	
-	if (!(fp = fopen (path, mode)))
-		return NULL;
-	
-	return g_mime_stream_file_new (fp);
-}
-
-
 /**
  * g_mime_stream_file_get_owner:
  * @stream: a #GMimeStreamFile
